@@ -203,7 +203,8 @@ mod test_png {
         case("circle_binned", 1.0),
         case("stacked_bar_h", 2.0),
         case("bar_chart_trellis_compact", 2.0),
-        case("line_with_log_scale", 2.0)
+        case("line_with_log_scale", 2.0),
+        case("remote_images", 1.0),
     )]
     fn test(
         name: &str,
